@@ -1,4 +1,4 @@
-#ifdef SYSV
+#if defined(SYSV)
 #ifndef _FLOCK_EMULATE_INCLUDED
 #define _FLOCK_EMULATE_INCLUDED
 
