@@ -1,6 +1,6 @@
 /*
  * maillock.c	Locks the mailbox with a .lock file.
- *		This code is based in the impementation
+ *		This code is based in the implementation
  *		in mail.local.c as shipped with sendmail 8.7.x
  */
 
@@ -43,7 +43,7 @@ int retries;
 		if ((fd = open(lockfile, O_WRONLY|O_EXCL|O_CREAT, 0644)) > 0) {
 			islocked = 1;
 			close(fd);
-			return;
+			return 0;
 		}
 		if (stat(lockfile, &st) < 0) {
 			if (statfailed++ > 5)
@@ -57,7 +57,7 @@ int retries;
 			continue;
 		unlink(lockfile);
 	}
-	return 0;
+	return -1;
 }
 
 void mailunlock()
