@@ -26,7 +26,9 @@ static char SccsId[] = "@(#)@(#)pop_dropcopy.c	2.6  2.6 4/3/91";
 #ifdef SYSV
 # include	<string.h>
 # include 	<unistd.h>	/* Maybe /sys/unistd.h on HPUX */
-# include	"flock.h"
+# ifndef LINUX
+#  include	"flock.h"
+# endif
 # ifndef index
 #  define	index(s,c)		strchr(s,c)
 # endif
@@ -47,7 +49,7 @@ static char SccsId[] = "@(#)@(#)pop_dropcopy.c	2.6  2.6 4/3/91";
 #endif
 
 #ifdef MAILOCK
-# include <maillock.h>
+# include "maillock.h"
 #endif
 
 #if defined(SYSV) && !defined(L_XTND)
@@ -911,7 +913,7 @@ struct passwd	*	pwp;
 
 #ifdef MAILOCK
     /*  Lock the maildrop */
-    if (maillock(p->user,1) != 0)
+    if (maillock(p->user,5) != 0)
             return pop_msg(p,POP_FAILURE, "maillock: '%s'", p->temp_drop);
 #endif
 
