@@ -461,12 +461,20 @@ struct passwd *pw;
 
     /*  We don't accept connections from users with null passwords */
     /*  Compare the supplied password with the password file entry */
+#if 0 /* Where does pw_encrypt come from ?? */
     if ((pw->pw_passwd == NULL) || (*pw->pw_passwd == '\0') || 
 	    (strcmp(crypt(p->pop_parm[1], pw->pw_passwd), pw->pw_passwd) &&
 	     strcmp(pw_encrypt(p->pop_parm[1], pw->pw_passwd), pw->pw_passwd))){
 	sleep(SLEEP_SECONDS);
 	return (pop_msg(p,POP_FAILURE, pwerrmsg, p->user));
     }
+#else
+    if ((pw->pw_passwd == NULL) || (*pw->pw_passwd == '\0') || 
+	    (strcmp(crypt(p->pop_parm[1], pw->pw_passwd), pw->pw_passwd))) {
+	sleep(SLEEP_SECONDS);
+	return (pop_msg(p,POP_FAILURE, pwerrmsg, p->user));
+    }
+#endif
 
     return(POP_SUCCESS);
 }
