@@ -15,7 +15,9 @@ static char SccsId[] = "@(#)@(#)pop_updt.c	2.3  2.3 3/20/91";
 #ifdef SYSV
 # include <string.h>
 # include <unistd.h>
-# include "flock.h"
+# ifndef LINIX
+#  include "flock.h"
+# endif
 #else
 # include <strings.h>
 #endif
@@ -24,7 +26,7 @@ static char SccsId[] = "@(#)@(#)pop_updt.c	2.3  2.3 3/20/91";
 #include "popper.h"
 
 #ifdef MAILOCK
-# include <maillock.h>
+# include "maillock.h"
 #endif
 
 #if defined(SYSV) && !defined(L_XTND)
@@ -101,7 +103,7 @@ POP     *   p;
 
 #ifdef MAILOCK
 	/* Use SVR4 mail locking */
-	if (maillock(p->user, 1) != 0)
+	if (maillock(p->user, 5) != 0)
 	    return(pop_msg(p,POP_FAILURE,"maillock: '%s' (%d)",p->temp_drop,errno));
 #endif
     }
